@@ -49,7 +49,7 @@ elif detector.board.any_raspberry_pi_40_pin:
 elif detector.board.any_raspberry_pi_cm:
     from adafruit_blinka.board.raspi_cm import *
 
-elif detector.board.RASPBERRY_PI_B_REV1:
+elif detector.board.RASPBERRY_PI_A or detector.board.RASPBERRY_PI_B_REV1:
     from adafruit_blinka.board.raspi_1b_rev1 import *
 
 elif detector.board.RASPBERRY_PI_B_REV2:
@@ -67,6 +67,9 @@ elif board_id == ap_board.ORANGE_PI_PC:
 elif board_id == ap_board.ORANGE_PI_R1:
     from adafruit_blinka.board.orangepir1 import *
 
+elif board_id == ap_board.ORANGE_PI_ZERO:
+    from adafruit_blinka.board.orangepizero import *
+
 elif board_id == ap_board.GIANT_BOARD:
     from adafruit_blinka.board.giantboard import *
 
@@ -89,16 +92,19 @@ elif board_id == ap_board.ODROID_C2:
     from adafruit_blinka.board.odroidc2 import *
 
 elif board_id == ap_board.ODROID_N2:
-   from adafruit_blinka.board.odroidn2 import *
+    from adafruit_blinka.board.odroidn2 import *
 
 elif board_id == ap_board.DRAGONBOARD_410C:
     from adafruit_blinka.board.dragonboard_410c import *
 
+elif board_id == ap_board.FTDI_FT232H:
+    from adafruit_blinka.board.ftdi_ft232h import *
+
 elif "sphinx" in sys.modules:
     pass
 
 else:
-    raise NotImplementedError("Board not supported")
+    raise NotImplementedError("Board not supported {}".format(board_id))
 
 def I2C():
     """The singleton I2C interface"""
